@@ -7,7 +7,7 @@ use File::Copy;
 use Archive::SevenZip 'AZ_OK';
 
 use vars qw($VERSION);
-$VERSION= '0.03';
+$VERSION= '0.04';
 
 sub new {
     my( $class, %options )= @_;
@@ -21,6 +21,19 @@ sub sevenZip { $_[0]->{sevenZip} }
 
 Archive::SevenZip::API::ArchiveZip - Archive::Zip compatibility API
 
+=head1 SYNOPSIS
+
+  my $ar = Archive::SevenZip->archiveZipApi(
+      find => 1,
+      archivename => $archivename,
+      verbose => $verbose,
+  );
+
+This module implements just enough of the L<Archive::Zip>
+API to pass some of the Archive::Zip test files. Ideally you can
+use this API to enable a script that uses Archive::Zip
+to also read other archive files supported by 7z.
+
 =cut
 
 sub writeToFileNamed {
